@@ -156,7 +156,9 @@ def WKT2EPSG(wkt):
     if not wkt:
         return None
 
-    ccrs = CRS.from_wkt(wkt.replace('\n', '').replace('\r', '').replace(' ', ''))\
+    wkt = ''.join([line.strip().replace('\n', '').replace('\r', '')
+                   for line in wkt.splitlines()])
+    ccrs = CRS.from_wkt(wkt)
 
     if not ccrs.is_bound:
         epsg = ccrs.to_epsg()
